@@ -9,6 +9,7 @@ import narwhals as nw
 from tests.utils import (
     DUCKDB_VERSION,
     PANDAS_VERSION,
+    POLARS_VERSION,
     Constructor,
     ConstructorEager,
     assert_equal_data,
@@ -272,3 +273,69 @@ def test_rank_expr_in_over_desc(
     )
     expected_data = {"a": expected_over_desc[method]}
     assert_equal_data(result, expected_data)
+
+
+def test_rank_with_order_by(
+    constructor: Constructor, request: pytest.FixtureRequest
+) -> None:
+    if "dask" in str(constructor):
+        # `rank` is not implemented in Dask
+        request.applymarker(pytest.mark.xfail)
+    if "pandas_pyarrow" in str(constructor) and PANDAS_VERSION < (2, 1):
+        pytest.skip(reason="bug in old version")
+    if "polars" in str(constructor) and POLARS_VERSION < (1, 10):
+        pytest.skip(reason="too old")
+    if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
+        pytest.skip(reason="too old version")
+
+    df = nw.from_native(
+        constructor(
+            {"a": [1, 1, 2, 2, 3, 3], "b": [3, None, 4, 3, 5, 6], "i": list(range(6))}
+        )
+    )
+    result = df.with_columns(c=nw.col("a").rank("ordinal").over(order_by="b")).sort("i")
+    expected = {
+        "a": [1, 1, 2, 2, 3, 3],
+        "b": [3, None, 4, 3, 5, 6],
+        "i": [0, 1, 2, 3, 4, 5],
+        "c": [2, 1, 4, 3, 5, 6],
+    }
+    assert_equal_data(result, expected)
+
+
+def test_rank_with_order_by_and_partition_by(
+    constructor: Constructor, request: pytest.FixtureRequest
+) -> None:
+    if any(x in str(constructor) for x in ("dask", "pyarrow_table", "cudf")):
+        # `rank` is not implemented in Dask
+        # pyarrow only supports aggregations in `over(partition_by=...)`
+        # cudf: https://github.com/rapidsai/cudf/issues/18159
+        request.applymarker(pytest.mark.xfail)
+    if "pandas_pyarrow" in str(constructor) and PANDAS_VERSION < (2, 1):
+        pytest.skip(reason="bug in old version")
+    if "polars" in str(constructor) and POLARS_VERSION < (1, 10):
+        pytest.skip(reason="too old")
+    if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
+        pytest.skip(reason="too old version")
+
+    df = nw.from_native(
+        constructor(
+            {
+                "a": [1, 1, 2, 2, 3, 3],
+                "b": [3, None, 4, 3, 5, 6],
+                "i": list(range(6)),
+                "g": ["x", "x", "x", "y", "y", "y"],
+            }
+        )
+    )
+    result = df.with_columns(c=nw.col("a").rank("ordinal").over("g", order_by="b")).sort(
+        "i"
+    )
+    expected = {
+        "a": [1, 1, 2, 2, 3, 3],
+        "b": [3, None, 4, 3, 5, 6],
+        "i": [0, 1, 2, 3, 4, 5],
+        "g": ["x", "x", "x", "y", "y", "y"],
+        "c": [2, 1, 3, 1, 2, 3],
+    }
+    assert_equal_data(result, expected)
