@@ -1,12 +1,14 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Mapping
+from typing import TYPE_CHECKING, Any
 
 import pytest
 
 import narwhals as nw
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
     from tests.utils import ConstructorEager
 
 pytest.importorskip("polars")
